@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2009 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmActionForm.php,v 1.1 2009/01/11 05:34:31 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmActionForm.php,v 1.2 2009/02/14 04:32:56 seasonstream Exp $
  * @link      http://syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_FRAMEWORK_DIR . '/core/SyL_ActionForm.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2009 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmActionForm.php,v 1.1 2009/01/11 05:34:31 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmActionForm.php,v 1.2 2009/02/14 04:32:56 seasonstream Exp $
  * @link      http://syl.jp/
  */
 class SyL_AdmActionForm extends SyL_ActionForm
@@ -98,13 +98,6 @@ class SyL_AdmActionForm extends SyL_ActionForm
      * @var array
      */
     var $related_links = array();
-    /**
-     * 検索項目名の接頭辞
-     * 
-     * @access private
-     * @var string
-     */
-    var $search_item_prefix = 'cl.';
 
     /**
      * 機能タイプを取得する
