@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2009 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Adm.php,v 1.2 2009/01/11 05:34:31 seasonstream Exp $
+ * @version   CVS: $Id: Adm.php,v 1.3 2009/02/14 04:32:56 seasonstream Exp $
  * @link      http://syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -40,6 +40,10 @@ SyL_Loader::lib('DB');
  * ファイル処理クラス
  */
 SyL_Loader::lib('File');
+/**
+ * Xml読み込みクラス
+ */
+SyL_Loader::lib('Xml.Reader');
 
 /**
  * ADM用アクションフォームとDAO用テーブルクラスを作成するクラス
@@ -48,7 +52,7 @@ SyL_Loader::lib('File');
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2009 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Adm.php,v 1.2 2009/01/11 05:34:31 seasonstream Exp $
+ * @version   CVS: $Id: Adm.php,v 1.3 2009/02/14 04:32:56 seasonstream Exp $
  * @link      http://syl.jp/
  */
 class Adm extends AppAction
@@ -84,7 +88,6 @@ class Adm extends AppAction
         $action_name = $data->geta('a', 0);
         $controller_dir = dirname($data->geta('c', 0));
         $table_name  = $data->geta('t', 0);
-        $smarty_flag = $data->is('s');
 
         $cmd->stdout("  parameters checking...");
 
@@ -110,6 +113,14 @@ class Adm extends AppAction
             exit;
         }
 
+        // -------------------------------------------------
+        // アクションディレクトリ名チェック
+        // -------------------------------------------------
+        if (!$action_name) {
+            trigger_error("[SyL error] Action directory (-a) not found", E_USER_ERROR);
+            exit;
+        }
+
         // -------------------------------------------------
         // テーブル名チェック
         // -------------------------------------------------
@@ -121,50 +132,44 @@ class Adm extends AppAction
         $mkdirs = array();
 
         // -------------------------------------------------
-        // プロジェクトディレクトリチェック
+        // アクションディレクトリチェック
         // -------------------------------------------------
         $cmd->stdout("  project application directory checking...");
 
-        $action_dir   = '';
-        $template_dir = '';
-        $action_names = array();
-        if ($action_name) {
-            $action_dir   = "{$app_dir}/actions";
-            $template_dir = "{$app_dir}/templates";
-
-            if (substr($action_name, 0, 1) == '/') {
-                $action_name = substr($action_name, 1);
+        $action_dir   = "{$app_dir}/actions";
+        $template_dir = "{$app_dir}/templates";
+        if ($action_name[0] == '/') {
+            $action_name = substr($action_name, 1);
+        }
+        $action_names = array_map('ucfirst', explode('/', $action_name));
+        $action_name = implode('/', $action_names);
+        if (!is_dir("{$action_dir}/{$action_name}")) {
+            if ($cmd->getInput('', "Action directory not found. create directory ? ({$action_dir}/{$action_name}) [Y/n]:") != 'Y') {
+                return;
             }
-            $action_names = array_map('ucfirst', explode('/', $action_name));
-            $action_name = implode('/', $action_names);
-            if (!is_dir("{$action_dir}/{$action_name}")) {
-                if ($cmd->getInput('', "Action directory not found. create directory ? ({$action_dir}/{$action_name}) [Y/n]:") != 'Y') {
-                    return;
-                }
+        }
+        if (!is_dir("{$template_dir}/{$action_name}")) {
+            if ($cmd->getInput('', "Template directory not found. create directory ? ({$template_dir}/{$action_name}) [Y/n]:") != 'Y') {
+                return;
             }
-            if (!is_dir("{$template_dir}/{$action_name}")) {
-                if ($cmd->getInput('', "Template directory not found. create directory ? ({$template_dir}/{$action_name}) [Y/n]:") != 'Y') {
-                    return;
-                }
-            }
-            foreach ($action_names as $tmp) {
-                if ($tmp != '') {
-                    $action_dir .= "/{$tmp}";
-                    if (file_exists($action_dir)) {
-                        if (!is_dir($action_dir)) {
-                            trigger_error("[SyL error] Invalid action directory check. already file exist ({$action_dir})", E_USER_ERROR);
-                        }
-                    } else {
-                        $mkdirs[] = $action_dir;
+        }
+        foreach ($action_names as $tmp) {
+            if ($tmp != '') {
+                $action_dir .= "/{$tmp}";
+                if (file_exists($action_dir)) {
+                    if (!is_dir($action_dir)) {
+                        trigger_error("[SyL error] Invalid action directory check. already file exist ({$action_dir})", E_USER_ERROR);
                     }
-                    $template_dir .= "/{$tmp}";
-                    if (file_exists($template_dir)) {
-                        if (!is_dir($template_dir)) {
-                            trigger_error("[SyL error] Invalid template directory check. already file exist ({$template_dir})", E_USER_ERROR);
-                        }
-                    } else {
-                        $mkdirs[] = $template_dir;
+                } else {
+                    $mkdirs[] = $action_dir;
+                }
+                $template_dir .= "/{$tmp}";
+                if (file_exists($template_dir)) {
+                    if (!is_dir($template_dir)) {
+                        trigger_error("[SyL error] Invalid template directory check. already file exist ({$template_dir})", E_USER_ERROR);
                     }
+                } else {
+                    $mkdirs[] = $template_dir;
                 }
             }
         }
@@ -303,13 +308,28 @@ class Adm extends AppAction
                 }
                 $mkdirs[] = $js_dir;
             }
-
         }
 
         // -------------------------------------------------
-        // 設定ファイルチェック
+        // ADM設定ファイルチェック
         // -------------------------------------------------
-        $cmd->stdout("  project or application config checking...");
+        $cmd->stdout("  application adm config checking...");
+
+        $adm_config_file = $app_dir . '/config/adms.xml';
+        $adm_config = array();
+        if (is_file($adm_config_file)) {
+            $cmd->stdout("    - use adms.xml");
+            $cmd->stdout("      {$adm_config_file}");
+            $config =& SyL_Config::factory('adms');
+            $config->setConfigFiles($adm_config_file);
+            $config->parseXml();
+            $adm_config = $config->getConfig();
+        }
+        
+        // -------------------------------------------------
+        // SyL設定ファイルチェック
+        // -------------------------------------------------
+        $cmd->stdout("  project or application SyL config checking...");
 
         $project_config_file = $project_dir . '/config/defines.xml';
         $app_config_file     = $app_dir . '/config/defines.xml';
@@ -334,14 +354,32 @@ class Adm extends AppAction
             trigger_error("[SyL error] Table schema not found ({$table_name})", E_USER_ERROR);
         }
 
-        // 大文字統一
-        $table_primary = array_map('strtoupper', $table_primary);
-        for ($i=0; $i<count($table_uniques); $i++) {
-            $table_uniques[$i] = array_map('strtoupper', $table_uniques[$i]);
+        $cmd->stdout("    - table name");
+        $cmd->stdout("      {$table_name}");
+        if (count($table_primary) > 0) {
+            $cmd->stdout("    - primary key");
+            for ($i=0; $i<count($table_primary); $i++) {
+                $cmd->stdout("      " . $table_primary[$i]);
+                // 大文字統一
+                $table_primary[$i] = strtoupper($table_primary[$i]);
+            }
         }
-        foreach (array_keys($table_foreigns) as $key) {
-            $table_foreigns[$key] = array_change_key_case($table_foreigns[$key], CASE_UPPER);
-            $table_foreigns[$key] = array_map('strtoupper', $table_foreigns[$key]);
+        if (count($table_uniques) > 0) {
+            $cmd->stdout("    - unique key");
+            for ($i=0; $i<count($table_uniques); $i++) {
+                $cmd->stdout("      " . $table_primary[$i]);
+                // 大文字統一
+                $table_uniques[$i] = array_map('strtoupper', $table_uniques[$i]);
+            }
+        }
+        if (count($table_foreigns) > 0) {
+            $cmd->stdout("    - foreign key");
+            foreach (array_keys($table_foreigns) as $key) {
+                $cmd->stdout("      " . $key);
+                // 大文字統一
+                $table_foreigns[$key] = array_change_key_case($table_foreigns[$key], CASE_UPPER);
+                $table_foreigns[$key] = array_map('strtoupper', $table_foreigns[$key]);
+            }
         }
 
         // -------------------------------------------------
@@ -409,87 +447,85 @@ class Adm extends AppAction
             $template_file = SYL_PROJECT_DIR . '/var/templates/actions/Index.php';
             $create_file   = "{$action_dir}/" . basename($template_file);
             $cmd->stdout("  action template file {$template_file}");
-            $cmd->stdout("    -> generating form file {$create_file}");
+            $cmd->stdout("    -> generating action file {$create_file}");
 
             SyL_File::writeContents($create_file, str_replace($form_opp_search, $form_opp_replace, file_get_contents($template_file)));
 
             $template_file = SYL_PROJECT_DIR . '/var/templates/actions/Lst.php';
             $create_file   = "{$action_dir}/" . basename($template_file);
             $cmd->stdout("  action template file {$template_file}");
-            $cmd->stdout("    -> generating form file {$create_file}");
+            $cmd->stdout("    -> generating action file {$create_file}");
 
             SyL_File::writeContents($create_file, str_replace($form_opp_search, $form_opp_replace, file_get_contents($template_file)));
 
             $template_file = SYL_PROJECT_DIR . '/var/templates/actions/New.php';
             $create_file   = "{$action_dir}/" . basename($template_file);
             $cmd->stdout("  action template file {$template_file}");
-            $cmd->stdout("    -> generating form file {$create_file}");
+            $cmd->stdout("    -> generating action file {$create_file}");
 
             SyL_File::writeContents($create_file, str_replace($form_opp_search, $form_opp_replace, file_get_contents($template_file)));
 
             $template_file = SYL_PROJECT_DIR . '/var/templates/actions/Upd.php';
             $create_file   = "{$action_dir}/" . basename($template_file);
             $cmd->stdout("  action template file {$template_file}");
-            $cmd->stdout("    -> generating form file {$create_file}");
+            $cmd->stdout("    -> generating action file {$create_file}");
 
             SyL_File::writeContents($create_file, str_replace($form_opp_search, $form_opp_replace, file_get_contents($template_file)));
 
             $template_file = SYL_PROJECT_DIR . '/var/templates/actions/Del.php';
             $create_file   = "{$action_dir}/" . basename($template_file);
             $cmd->stdout("  action template file {$template_file}");
-            $cmd->stdout("    -> generating form file {$create_file}");
+            $cmd->stdout("    -> generating action file {$create_file}");
 
             SyL_File::writeContents($create_file, str_replace($form_opp_search, $form_opp_replace, file_get_contents($template_file)));
 
             $template_file = SYL_PROJECT_DIR . '/var/templates/actions/Fin.php';
             $create_file   = "{$action_dir}/" . basename($template_file);
             $cmd->stdout("  action template file {$template_file}");
-            $cmd->stdout("    -> generating form file {$create_file}");
+            $cmd->stdout("    -> generating action file {$create_file}");
 
             SyL_File::writeContents($create_file, str_replace($form_opp_search, $form_opp_replace, file_get_contents($template_file)));
 
             $template_file = SYL_PROJECT_DIR . '/var/templates/actions/Vew.php';
             $create_file   = "{$action_dir}/" . basename($template_file);
             $cmd->stdout("  action template file {$template_file}");
-            $cmd->stdout("    -> generating form file {$create_file}");
+            $cmd->stdout("    -> generating action file {$create_file}");
 
             SyL_File::writeContents($create_file, str_replace($form_opp_search, $form_opp_replace, file_get_contents($template_file)));
 
             // テンプレートファイル作成
-            $dir = ($smarty_flag) ? 'smarty' : 'default';
-
-            $template_file = SYL_PROJECT_DIR . "/var/templates/templates/{$dir}/Lst.html";
+            $template_file = SYL_PROJECT_DIR . "/var/templates/templates/Lst.html";
             $create_file   = "{$template_dir}/" . basename($template_file);
             $cmd->stdout("  template template file {$template_file}");
-            $cmd->stdout("    -> generating form file {$create_file}");
+            $cmd->stdout("    -> generating template file {$create_file}");
 
             SyL_File::writeContents($create_file, file_get_contents($template_file));
 
-            $template_file = SYL_PROJECT_DIR . "/var/templates/templates/{$dir}/New.html";
+            $template_file = SYL_PROJECT_DIR . "/var/templates/templates/New.html";
             $create_file   = "{$template_dir}/" . basename($template_file);
             $cmd->stdout("  template template file {$template_file}");
-            $cmd->stdout("    -> generating form file {$create_file}");
+            $cmd->stdout("    -> generating template file {$create_file}");
 
             SyL_File::writeContents($create_file, file_get_contents($template_file));
 
-            $template_file = SYL_PROJECT_DIR . "/var/templates/templates/{$dir}/Upd.html";
+            $template_file = SYL_PROJECT_DIR . "/var/templates/templates/Upd.html";
             $create_file   = "{$template_dir}/" . basename($template_file);
             $cmd->stdout("  template template file {$template_file}");
-            $cmd->stdout("    -> generating form file {$create_file}");
+            $cmd->stdout("    -> generating template file {$create_file}");
 
             SyL_File::writeContents($create_file, file_get_contents($template_file));
 
-            $template_file = SYL_PROJECT_DIR . "/var/templates/templates/{$dir}/Fin.html";
+            $template_file = SYL_PROJECT_DIR . "/var/templates/templates/Fin.html";
             $create_file   = "{$template_dir}/" . basename($template_file);
             $cmd->stdout("  template template file {$template_file}");
-            $cmd->stdout("    -> generating form file {$create_file}");
+            $cmd->stdout("    -> generating template file {$create_file}");
 
             SyL_File::writeContents($create_file, file_get_contents($template_file));
 
-            $template_file = SYL_PROJECT_DIR . "/var/templates/templates/{$dir}/Vew.html";
+            $template_file = SYL_PROJECT_DIR . "/var/templates/templates/Vew.html";
             $create_file   = "{$template_dir}/" . basename($template_file);
             $cmd->stdout("  template template file {$template_file}");
-            $cmd->stdout("    -> generating form file {$create_file}");
+            $cmd->stdout("    -> generating template file {$create_file}");
 
             SyL_File::writeContents($create_file, file_get_contents($template_file));
         }
@@ -539,6 +575,26 @@ class Adm extends AppAction
             }
         }
 
+        // adms.config に設定追加
+        if (isset($adm_config['base'])) {
+            $match = false;
+            if (isset($adm_config['adm'])) {
+                foreach ($adm_config['adm'] as $adm) {
+                    if ($adm['class'] == $form_class) {
+                        $match = true;
+                        break;
+                    }
+                }
+            }
+            if (!$match) {
+                $adm_xml = file_get_contents($adm_config_file);
+                $adm_xml = substr($adm_xml, 0, strrpos($adm_xml, '</syl-adms>'));
+                $adm_xml .= '<adm class="' . $form_class . '" link="" pathinfo="/' . $action_name . '/" enable="true" />';
+                $adm_xml .= "\n";
+                $adm_xml .= '</syl-adms>';
+                SyL_File::writeContents($adm_config_file, $adm_xml);
+            }
+        }
 
         // -------------------------------------------------
         // 結果表示
