@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2009 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Index.php,v 1.2 2009/01/11 05:34:31 seasonstream Exp $
+ * @version   CVS: $Id: Index.php,v 1.3 2009/02/14 04:32:56 seasonstream Exp $
  * @link      http://syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -42,13 +42,13 @@ SyL_Loader::lib('DB');
 SyL_Loader::lib('File');
 
 /**
- * ADM用アクションフォームとDAO用テーブルクラスを作成するクラス
+ * scaffold.php の起動アクションファイル
  *
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2009 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Index.php,v 1.2 2009/01/11 05:34:31 seasonstream Exp $
+ * @version   CVS: $Id: Index.php,v 1.3 2009/02/14 04:32:56 seasonstream Exp $
  * @link      http://syl.jp/
  */
 class Index extends AppAction
@@ -75,6 +75,11 @@ class Index extends AppAction
         }
 
         switch (strtolower($data->get(1))) {
+        case 'base':
+            include_once 'Base.php';
+            $obj =& new Base();
+            $obj->execute($data, $context);
+            break;
         case 'adm':
             include_once 'Adm.php';
             $obj =& new Adm();
@@ -91,7 +96,7 @@ class Index extends AppAction
             $obj->execute($data, $context);
             break;
         default:
-            trigger_error("[SyL error] Command type not found (" . $data->get(1) . ")", E_USER_ERROR);
+            $this->displayDefault($cmd, $data->get(0));
         }
     }
 }
