@@ -6,7 +6,7 @@
  * @package   {APP_NAME}
  * @author    {author}
  * @copyright {copyright}
- * @version   $Id: AppAction.php,v 1.2 2009/01/11 05:34:34 seasonstream Exp $
+ * @version   $Id: AppAction.php,v 1.3 2009/02/14 04:32:56 seasonstream Exp $
  */
 class AppAction extends SyL_Action
 {
@@ -259,7 +259,8 @@ class AppAction extends SyL_Action
     {
         $help = <<<EOF
 Usage:
-  php {$file} adm -d <dir> -w <name> [-a <dir>] [-c <file>] -t <table> [-s]
+  php {$file} adm -d <dir> -w <name> -a <dir> [-c <file>] -t <table>
+  php {$file} base -d <dir> -w <name> -c <file> -u <url>
   php {$file} table -d <dir> [-w <name>] [-n <name>] [-p <name>] -t <table>
   php {$file} form -d <dir> [-w <name>] -f <name> [-n <name>] [-p <name>] -t <table>
   php {$file} [option]
@@ -267,10 +268,10 @@ Usage:
 Options:
   -d <dir>   project directory
   -w <name>  application name
-  -a <dir>   action directory for Adm Application (default: null)
+  -a <dir>   action directory from root action directory
   -c <file>  controller file (default: null)
   -t <table> database table name
-  -s         generate smarty template (default: PHP template)
+  -u <url>   controller url
   -f <name>  form class name. require SyL_Loader naming rule.
   -n <name>  table class name. require SyL_Loader naming rule. (default: table name)
   -p <name>  class prefix name. SyL_Loader naming rule. (default: null)
