@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006-2008 k.watanabe
+ * Copyright (C) 2006-2009 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,36 +25,36 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2008 k.watanabe
+ * @copyright 2006-2009 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Application.php,v 1.4 2008/09/29 14:41:37 seasonstream Exp $
- * @link      http://www.syl.jp/
+ * @version   CVS: $Id: Application.php,v 1.5 2009/01/11 05:34:33 seasonstream Exp $
+ * @link      http://syl.jp/
  * -----------------------------------------------------------------------------
  */
 
 /**
- * ץꥱ饹
+ * アプリケーション作成クラス
  *
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2008 k.watanabe
+ * @copyright 2006-2009 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Application.php,v 1.4 2008/09/29 14:41:37 seasonstream Exp $
- * @link      http://www.syl.jp/
+ * @version   CVS: $Id: Application.php,v 1.5 2009/01/11 05:34:33 seasonstream Exp $
+ * @link      http://syl.jp/
  */
 class Application extends AppAction
 {
-    var $c_action; // 󥸥
-    var $c_application; // 󥸥
-    var $c_controller; // 󥸥
-    var $c_template; // 󥸥
+    var $c_action; // インジェクション
+    var $c_application; // インジェクション
+    var $c_controller; // インジェクション
+    var $c_template; // インジェクション
 
     /**
-     * ץꥱ
+     * アプリケーション作成処理
      *
      * @access public
-     * @param object ǡ֥
-     * @param object ƥȥ֥
+     * @param object データオブジェクト
+     * @param object コンテキストオブジェクト
      */
     function execute(&$data, &$context)
     {
@@ -66,7 +66,7 @@ class Application extends AppAction
         $cmd =& $context->getConsole();
 
         // -------------------------------------------------
-        // ץȥǥ쥯ȥå
+        // プロジェクトディレクトリチェック
         // -------------------------------------------------
         if (!$project_dir) {
             trigger_error("[SyL error] Project directory (-d) not found", E_USER_ERROR);
@@ -81,7 +81,7 @@ class Application extends AppAction
         }
 
         // -------------------------------------------------
-        // ץꥱ̾å
+        // アプリケーション名チェック
         // -------------------------------------------------
         if (!$app_name) {
             trigger_error("[SyL error] Application name (-w) not found", E_USER_ERROR);
@@ -110,11 +110,11 @@ class Application extends AppAction
         }
 
         // -------------------------------------------------
-        // ȥեå
+        // コントローラファイルチェック
         // -------------------------------------------------
         if ($is_controller) {
             if (!$controller_file) {
-                // ǥեȤΥȥե
+                // デフォルトのコントローラファイル
                 $controller_file = "{$project_dir}public/{$app_name}.php";
             }
             if (file_exists($controller_file)) {
@@ -135,38 +135,36 @@ class Application extends AppAction
         }
 
         // -------------------------------------------------
-        // եå
+        // アクションファイルチェック
         // -------------------------------------------------
         $action_files = array('index');
 
         // -------------------------------------------------
-        // ƥץ졼ȥեå
+        // テンプレートファイルチェック
         // -------------------------------------------------
         $template_files = array('index');
 
         // -------------------------------------------------
-        // ץꥱ
+        // アプリケーション作成
         // -------------------------------------------------
         $this->c_application->trigger($cmd, $project_dir, $app_name);
 
         // -------------------------------------------------
-        // ȥե
+        // コントローラファイル作成
         // -------------------------------------------------
         if ($controller_file) {
             $this->c_controller->trigger($cmd, $project_dir, $app_name, $controller_file);
         }
 
         // -------------------------------------------------
-        // ե
+        // アクションファイル作成
         // -------------------------------------------------
         $this->c_action->trigger($cmd, $project_dir, $app_name, $action_files);
 
         // -------------------------------------------------
-        // ƥץ졼ȥե
+        // テンプレートファイル作成
         // -------------------------------------------------
         $this->c_template->trigger($cmd, $project_dir, $app_name, $template_files);
     }
 
 }
-
-?>
